TASK = 'task'
DATA = 'data'
LINK = 'link'
TARGET = 'target'

PROJECT_FLOW = 'project-flow'
CURRENT_ITERATION = 'current-iteration'
MESSAGE_CREATED = 'message-created'

NEXT_TASK_QUEUE = 'next-task-queue'
NEXT_TASK_PRIORITY = 'next-task-priority'

PART_TASK = 'task'
PART_MESSAGE = 'message'
